@@ -3,7 +3,6 @@ import os
 import re
 import shutil
 from pathlib import Path
-from typing import Optional
 
 from luscious_dl import __version__
 from luscious_dl.logger import logger
@@ -23,6 +22,15 @@ def cls() -> None:
   pass"""
 
 
+def inputs_string_to_list(inputs_string: str) -> list[str]:
+  """
+  Convert a string with comma-separated items into a list of strings.
+  :param inputs_string: a string with comma-separated items
+  :return: list of strings
+  """
+  return [input_.strip() for input_ in inputs_string.split(',')]
+
+
 def format_foldername(album, foldername_format: str = '%t') -> str:
   """
   Format album folder name.
@@ -53,7 +61,7 @@ def create_folder(directory: Path) -> None:
   """
   try:
     if not Path.exists(directory):
-      Path.mkdir(directory, exist_ok=True)
+      Path.mkdir(directory, parents=True, exist_ok=True)
       logger.info(f'Album folder created in: {directory}')
     else:
       logger.warn(f'Album folder already exist in: {directory}')
@@ -124,10 +132,10 @@ def get_root_path() -> Path:
   return Path(__file__).parent.parent
 
 
-def get_config_data() -> Optional[dict]:
+def get_config_data() -> dict:
   """
   Load and return config.json data.
-  :return: key value
+  :return: dictionary
   """
   try:
     with get_root_path().joinpath('config.json').open() as config:
@@ -135,7 +143,7 @@ def get_config_data() -> Optional[dict]:
       return data
   except Exception as e:
     logger.warning(f'Something went wrong loading config file: {e}')
-    return None
+    return {}
 
 
 def read_list() -> list[str]:
@@ -160,14 +168,15 @@ def create_default_files() -> None:
   root = get_root_path()
   if not Path.exists(root.joinpath('config.json')):
     data = {
-      "directory": os.path.normcase("./Albums/"),
+      "directory": "./albums/",
       "pool": os.cpu_count() or 1,
       "retries": 5,
       "timeout": 30,
       "delay": 0,
       "foldername_format": "%t",
       "gen_pdf": False,
-      "rm_origin_dir": False
+      "rm_origin_dir": False,
+      "group_by_user": False,
     }
     with root.joinpath('config.json').open('a+') as config_file:
       json.dump(data, config_file, indent=2)
@@ -220,7 +229,8 @@ def open_config_menu() -> None:
                           f'5 - Download Delay [Current: {data.get("delay")}]\n'
                           f'6 - Format output album folder name [Current: {data.get("foldername_format")}]\n'
                           f'7 - Generate PDF: [Current: {data.get("gen_pdf")}]\n'
-                          f'8 - Remove origin directory [Current: {data.get("rm_origin_dir")}]\n  '
+                          f'8 - Remove origin directory [Current: {data.get("rm_origin_dir")}]\n'
+                          f'9 - Group Albums by Uploader name [Current: {data.get("group_by_user")}]\n'
                           '0 - Back.\n'
                           '> ')
       cls()
@@ -262,6 +272,8 @@ def open_config_menu() -> None:
         data['gen_pdf'] = not data.get('gen_pdf')
       elif config_menu == '8':
         data['rm_origin_dir'] = not data.get('rm_origin_dir')
+      elif config_menu == '9':
+        data['group_by_user'] = not data.get('group_by_user')
       elif config_menu == '0':
         cls()
         break
